/**
 * @file
 * JavaScript behaviors for datetime fields.
 */

(function ($, Drupal) {
  'use strict';

  Date.prototype.datetimeNowDateInput = function() {
    let local = new Date(this);
    local.setMinutes(this.getMinutes() - this.getTimezoneOffset());
    return local.toJSON().slice(0,10);
  };

  Date.prototype.datetimeNowTimeInput = function(step = 1) {
    let local = new Date(this);
    local.setMinutes(this.getMinutes() - this.getTimezoneOffset());

    let time = local.toJSON();

    // If step is a multiple of 60, do not return seconds.
    if (step % 60 === 0) {
      return time.slice(11, 16);
    }
    return time.slice(11,19);
  };

  /**
   * Update a date field to today.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.webportal_service_datetime_now = {
    attach: function (context, settings) {
      $(once('datetime-now', '.datetime-now-wrapper', context)).each(function() {
        let $wrapper = $(this);
        let $now_button = $wrapper.find('.datetime-now');

        $now_button.on('click', function(e){
          let date = this.getAttribute('data-date-selector') + '-date';
          let time = this.getAttribute('data-date-selector') + '-time';
          let $date_element = $wrapper.find('[data-drupal-selector="' + date + '"]');
          let $time_element = $wrapper.find('[data-drupal-selector="' + time + '"]');

          let step = $time_element.attr('step');
          let today = new Date().datetimeNowDateInput();
          let now = new Date().datetimeNowTimeInput(step);

          $date_element.val(today);
          $time_element.val(now);

          return false;
        });
      });
    }
  };

})(jQuery, Drupal);
